<!--
 Copyright European Organization for Nuclear Research (CERN)

 Licensed under the Apache License, Version 2.0 (the "License");
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 http://www.apache.org/licenses/LICENSE-2.0

 Authors:
 - Cedric Serfon, <cedric.serfon@cern.ch>, 2019
-->

$var title: Account Usage History
$var script: <script src="/static/account_usage_history.js"></script><script src="static/chosen.jquery.min.js"></script><script src="/static/jquery.multiple.select.js"></script><link rel="stylesheet" href="/static/multiple-select.css">


<div class="row">
  <div class="large-4 columns">
    <div>
      <select id="accountselect" data-placeholder="Choose an account..." class="chosen-select" multiple style="width:500px;" tabindex="4"></select>
    </div>
    <div>
      <select id="rseselect" data-placeholder="Choose an RSE..." class="chosen-select" multiple style="width:500px;" tabindex="4"></select>
    </div>
  </div>
  <div class="large-8 columns panel">
    <div id="rseplot"></div>
  </div>
</div>

