/* Copyright European Organization for Nuclear Research (CERN)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Authors:
 * - Thomas Beermann, <thomas.beermann@cern.ch>, 2016
 */

get_version = function() {
    version = '-';
    jQuery.ajax({
        url: '/static/webui_version',
        async: false,
        success: function(data)
        {
            version = data;
        },
    });
    return version;
}
