
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.21.0',
    'branch_nick': 'patch-0-Release__1_21_0_preparation',
    'revision_id': '7e32dee2c3af1fd51417481483449ca3d9c3bf28',
    'revno': 9000
}
